@@ -201,11 +201,13 @@ class Callback(object):
     # via un partenaire
     def buying_offer_bluebase(self, **params):
         params["solde"] = params["amount"]
+        params["version"] = "2"
         data_headers = params["headers"]
         token = params["token"]
         response = self.client_blue.post(
             "/ussd_buy_recharge", auth=(token, ""), headers=data_headers, json=params
         )
+        LOGS.logger.info("params activation depuis bluebase: {}".format(params))
         LOGS.logger.info("resultat activation depuis bluebase: {}".format(response))
         return response
 
@@ -233,7 +235,6 @@ class Callback(object):
             result = self.buying_bip_bundle(**params)
         if type(result) == tuple:
             result = result[0]
-        LOGS.logger.info(result)
         response = {"data": result["content"], "status": result["status"]}
         LOGS.logger.info(response)
         return response
@@ -317,6 +318,7 @@ class Callback(object):
                 params[p] = ""
         if "offer_name" in params and params["offer_name"] == "credit_transfer_partner":
             bundle_name = "mobile_money: achat_credit_bip"
+            params["offer_ref"] = "000432"
         elif "offer_name" in params and params["offer_name"] == "buy_offer_partner":
             bundle_name = "mobile_money: {}".format(params["bundle_name"])
         else:
