@@ -45,7 +45,7 @@ def notify(partner_ref):
         """ le check activation sur bluebase""".format(partner_ref)
     )
     fromaddr = "ussd@si.blueline.mg"
-    toaddr = ["moria.miraifahasoavana@staff.blueline.mg"]
+    toaddr = ["moria.miraifahasoavana@staff.blueline.mg", "dev@si.blueline.mg"]
     msg = MIMEMultipart()
     msg['From'] = fromaddr
     msg['Subject'] = "Check activation bluebase"
